# thejourneyplanner

![Continuous Integration (CI) Tests](https://github.com/unkokaeru/thejourneyplanner/actions/workflows/continuous_integration.yml/badge.svg)

Plan a quick walk in the car!

## Installation

To install thejourneyplanner, simply run:

```bash
pip install thejourneyplanner
```

## Usage

After installation, you can use the package by executing:

```bash
thejourneyplanner
```

## Documentation
For more information, you can find the documentation within the `docs` directory or on the project's [GitHub Pages](https://unkokaeru.github.io/thejourneyplanner/).

## Contributing

Contributions are welcome! Please refer to our `CONTRIBUTING.md` for more information.

## License

This project is licensed under the MIT License - see the `LICENSE.md` file for details.